@@ -1,6 +1,6 @@
 use crate::models::{Range, State, Token, WCode, WFuncVariant, WTokens};
 use crate::parser::WParser;
-use crate::utils::{first_special_instance, last_function, skin_content, special_pairs, WFunc};
+use crate::utils::{Utils, WFunc};
 use itertools::Itertools;
 
 pub trait WEval {
@@ -41,19 +41,19 @@ impl WEval for State {
     fn eval(&self, data: WTokens) -> WTokens {
         let mut new_code = data.clone();
 
-        while let Some((first_func_pos, func)) = last_function(&new_code) {
-            let first = first_special_instance("(".to_string(), &new_code);
+        while let Some((first_func_pos, func)) = new_code.last_function() {
+            let first = new_code.first_special_instance("(".to_string());
             let second = match first {
-                Some(x) => special_pairs(("(".to_string(), ")".to_string()), &new_code, &x),
+                Some(x) => new_code.special_pairs(("(".to_string(), ")".to_string()), &x),
                 None => None,
             };
 
             if let (Some(x), Some(y)) = (first, second) {
                 let mut result = new_code[x + 1..y].to_vec();
-                if let Some((first_func_pos, func)) = last_function(&result) {
+                if let Some((first_func_pos, func)) = result.last_function() {
                     let code_to_evaluate = result[..first_func_pos].to_vec();
                     self.dissolve(&mut result, func, first_func_pos, code_to_evaluate);
-                    skin_content(&mut result);
+                    result.skin_content();
                     new_code.splice(x + 1..y, result);
                 } else {
                     new_code.splice(x..=y, result);
