@@ -27,7 +27,7 @@ pub fn expand_string(text: String) -> String {
     RE.replace_all(&text, |caps: &Captures| {
         let collection = caps[2]
             .chars()
-            .fold("".to_string(), |acc, x| format!("{} {}", acc, x));
+            .fold("".to_string(), |acc, x| format!("{} '{}'", acc, x));
         format!("{}{{ {} }}{}", &caps[1], &collection[1..], &caps[3])
     })
     .to_string()
